# External Dependencies

To reduce the amount of data needed to fetch by the build script we instead copy
the corresponding files in this repository while keeping their license information.

Since we often only need a subset of the libraries we thus further reduce the
size.

The `CMakeLists.txt` files in each directory are custom provided.

## List of Dependencies

The following is a list of the dependencies with links to their project page.

- [glslang](https://github.com/KhronosGroup/glslang)
- [SPIRV-Reflect](https://github.com/KhronosGroup/SPIRV-Reflect)
- [stb](https://github.com/nothings/stb)
- [VulkanMemoryAllocator](https://github.com/GPUOpen-LibrariesAndSDKs/VulkanMemoryAllocator)
- [Volk](https://github.com/zeux/volk)
- [Vulkan Headers](https://github.com/KhronosGroup/Vulkan-Headers)
